@@ -1,13 +1,14 @@
 from typing import List, Optional, TYPE_CHECKING, Union
 
-from mstrio.access_and_security.security_filter import (AttributeRef, ObjectInformation,
-                                                        Qualification)
+from mstrio.access_and_security.security_filter import (
+    AttributeRef, ObjectInformation, Qualification
+)
 from mstrio.api import changesets, security_filters
 from mstrio.api.security_filters import ShowExpressionAs, UpdateOperator
 from mstrio.object_management import full_search
 from mstrio.users_and_groups import User, UserGroup
 from mstrio.utils import helper
-from mstrio.utils.entity import Entity, ObjectSubTypes, ObjectTypes, DeleteMixin
+from mstrio.utils.entity import DeleteMixin, Entity, ObjectSubTypes, ObjectTypes
 
 if TYPE_CHECKING:
     from mstrio.connection import Connection
@@ -73,6 +74,7 @@ class SecurityFilter(Entity, DeleteMixin):
     _OBJECT_TYPE = ObjectTypes.SECURITY_FILTER
     _OBJECT_SUBTYPE = ObjectSubTypes.MD_SECURITY_FILTER.value
     _SIZE_LIMIT = 10000000  # this sets desired chunk size in bytes
+    _DELETE_NONE_VALUES_RECURSION = True
 
     def __init__(self, connection: "Connection", id: str, name: Optional[str] = None):
         """Initialize security filter object by its identifier.
@@ -157,9 +159,9 @@ class SecurityFilter(Entity, DeleteMixin):
         Args:
             attr (str, optional): Attribute name to be fetched.
             fetch_definition (bool, optional): flag which indicates whether
-                definition of security filter is fetched. By defualt `True`.
+                definition of security filter is fetched. By default `True`.
             fetch_members (bool, optional): flag which indicates whether
-                members of security filter is fetched. By defualt `True`.
+                members of security filter is fetched. By default `True`.
 
         Raises:
             ValueError: if `attr` cannot be fetched.
@@ -182,7 +184,7 @@ class SecurityFilter(Entity, DeleteMixin):
             "qualification": qualification,
             "topLevel": top_level,
             "bottomLevel": bottom_level
-        })
+        }, recursion=True)
 
     @staticmethod
     def __create_update_helper(func, connection: "Connection",
@@ -211,7 +213,7 @@ class SecurityFilter(Entity, DeleteMixin):
             connection=connection, changeset_id=changeset_id, throw_error=False, id=id,
             body=SecurityFilter.__prepare_body(qualification, id, name, folder_id, description,
                                                top_level_dicts, bottom_level_dicts))
-        # there might be a case when response below is correct but commiting
+        # there might be a case when response below is correct but committing
         # changes is incorrect
         res_commit = changesets.commit_changeset_changes(connection, changeset_id,
                                                          throw_error=False)
