@@ -1,4 +1,5 @@
 from enum import auto
+import logging
 from typing import List, Optional, TYPE_CHECKING, Union
 
 from mstrio import config
@@ -6,13 +7,15 @@ from mstrio.api import datasources, objects
 from mstrio.datasources.datasource_login import DatasourceLogin
 from mstrio.users_and_groups.user import User
 from mstrio.utils import helper
-from mstrio.utils.entity import DeleteMixin, CopyMixin, Entity, ObjectTypes
+from mstrio.utils.entity import CopyMixin, DeleteMixin, Entity, ObjectTypes
 from mstrio.utils.enum_helper import AutoName, get_enum_val
 from mstrio.utils.helper import get_objects_id
 
 if TYPE_CHECKING:
     from mstrio.connection import Connection
 
+logger = logging.getLogger(__name__)
+
 
 def list_datasource_connections(connection: "Connection", to_dictionary: bool = False,
                                 limit: Optional[int] = None,
@@ -54,8 +57,8 @@ class DriverType(AutoName):
 
 class ExecutionMode(AutoName):
     RESERVED = auto()
-    ASYNCH_CONNECTION = auto()
-    ASYNCH_STATEMENT = auto()
+    ASYNC_CONNECTION = auto()
+    ASYNC_STATEMENT = auto()
     SYNCHRONOUS = auto()
 
 
@@ -106,6 +109,7 @@ class DatasourceConnection(Entity, CopyMixin, DeleteMixin):
             [EnumDSSXMLAccessRightFlags].
         acl: Object access control list
     """
+    _DELETE_NONE_VALUES_RECURSION = True
     _OBJECT_TYPE = ObjectTypes.DBCONNECTION
     _FROM_DICT_MAP = {
         **Entity._FROM_DICT_MAP,
@@ -156,7 +160,7 @@ class DatasourceConnection(Entity, CopyMixin, DeleteMixin):
         "driver_type": str,
         "database_type": str,
         "database_version": str,
-        "datasource_login": str
+        "datasource_login": dict
     }
 
     def __init__(self, connection: "Connection", name: Optional[str] = None,
@@ -258,6 +262,9 @@ class DatasourceConnection(Entity, CopyMixin, DeleteMixin):
             database_type: Database type
             database_version: Database version
         """
+        datasource_login = {
+            'id': get_objects_id(datasource_login, DatasourceLogin)
+        } if datasource_login else None
         func = self.alter
         args = func.__code__.co_varnames[:func.__code__.co_argcount]
         defaults = func.__defaults__  # type: ignore
@@ -355,11 +362,13 @@ class DatasourceConnection(Entity, CopyMixin, DeleteMixin):
             "driverType": get_enum_val(driver_type, DriverType),
             "oauthParameter": oauth_parameter
         }
-        body = helper.delete_none_values(body)
+        body = helper.delete_none_values(body, recursion=True)
         response = datasources.create_datasource_connection(connection, body).json()
         if config.verbose:
-            print("Successfully created datasource connection named: '{}' with ID: '{}'".format(
-                response.get('name'), response.get('id')))
+            logger.info(
+                f"Successfully created datasource connection named: '{response.get('name')}' "
+                f"with ID: '{response.get('id')}'"
+            )
         return cls.from_dict(source=response, connection=connection)
 
     def test_connection(self) -> bool:
