@@ -43,6 +43,7 @@ class Dbms(EntityBase):
         type: Database management system (DBMS) type.
         version: Database management system (DBMS) version.
     """
+    _DELETE_NONE_VALUES_RECURSION = True
     _OBJECT_TYPE = ObjectTypes.NONE
     _FROM_DICT_MAP = {}  # map attributes to Enums and Composites
     _DBMS_CACHE = set()
@@ -76,7 +77,7 @@ class Dbms(EntityBase):
                                  version=temp_dbms["version"])
             else:
                 identifier = name if name else id
-                raise ValueError("There is no Dbms: '{}'".format(identifier))
+                raise ValueError(f"There is no Dbms: '{identifier}'")
 
     def _init_variables(self, **kwargs) -> None:
         """Set object attributes by providing keyword args."""
