@@ -13,6 +13,7 @@ class ObjectTypes(Enum):
     FUNCTION = 11
     ATTRIBUTE = 12
     FACT = 13
+    DIMENSION = 14
     TABLE = 15
     SHORTCUT_TYPE = 18
     MONITOR = 20
@@ -68,10 +69,18 @@ class ObjectTypes(Enum):
 class ObjectSubTypes(Enum):
     OLAP_CUBE = 776
     SUPER_CUBE = 779
+    FUNCTION = 2816
     USER = 8704
     USER_GROUP = 8705
     SEARCH = 9984
+    FUNCTION_PACKAGE_DEFINITION = 10752
     MD_SECURITY_FILTER = 14848
+    ATTRIBUTE = 3072
+    ATTRIBUTE_ABSTRACT = 3075
+    ATTRIBUTE_FORM = 5376
+    ATTRIBUTE_RECURSIVE = 3076
+    ATTRIBUTE_ROLE = 3073
+    ATTRIBUTE_TRANSFORMATION = 3074
     NONE = None
 
     def __new__(cls, value):
